#
# spec file for package scrollkeeper (Version 0.3.14)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           scrollkeeper
BuildRequires:  docbook_4 fdupes intltool libxslt-devel perl-XML-Parser sgml-skel
%define xmlcatalog	%{_sysconfdir}/xml/catalog
%define my_localstatedir /var
Summary:        Cataloging System for Documentation
Version:        0.3.14
Release:        253.4.1
Source0:        scrollkeeper-%{version}.tar.bz2
Source1:        logrotate.%{name}
# PATCH-FIX-OPENSUSE scrollkeeper-0.3.14-rebuilddb.diff bnc96609 ke@suse.de
Patch:          scrollkeeper-0.3.14-rebuilddb.diff
# PATCH-FIX-UPSTREAM scrollkeeper-0.3.14-createdbdir.diff bnc230786 prusnak@suse.cz
Patch1:         scrollkeeper-0.3.14-createdbdir.diff
Requires:       docbook_4
Requires:       libxml2 >= 2.4.19
Requires:       libxslt
Requires:       %{name}-lang = %{version}
License:        LGPLv2.1+
Group:          Development/Libraries/C and C++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://scrollkeeper.sourceforge.net/
PreReq:         /bin/touch sgml-skel /usr/bin/xmlcatalog libxml2 docbook_4 libxslt
Requires(post): update-alternatives
Requires(postun): update-alternatives
# The build service fails to build the package because it doesn't really
# understand Requires(post), so use PreReq too (see bnc#439232).
%if %defined suse_version
PreReq:         update-alternatives
%endif
Suggests:       logrotate

%description 
ScrollKeeper is a cataloging system for documentation. It manages
documentation metadata (as specified by the Open Source Metadata
Framework (OMF)) and provides a simple API to allow help browsers to
find, sort, and search the document catalog.

It will also be able to communicate with catalog servers on the net to
search for documents which are not on the local system.



Authors:
--------
    Dan Mueth <muet@alumni.uchicago.edu>
    Eric Fischer <eric@eazel.com>
    Gregory Leblanc <gleblanc@cu-portland.edu>
    Laszlo Kovacs <laszlo.kovacs@sun.com>

%lang_package
%prep
%setup -q
%patch -p1 -b .rebuilddb
%patch1

%build
%configure \
  --localstatedir=%{my_localstatedir} \
  --with-omfdirs=/usr/share/omf:/usr/local/share/omf
%{__make} %{?jobs:-j%jobs}
xmlcatbin=/usr/bin/xmlcatalog
CATALOG=scrollkeeper.xml
$xmlcatbin --noout --create $CATALOG
$xmlcatbin --noout --add "public" \
  "-//OMF//DTD Scrollkeeper OMF Variant V1.0//EN" \
  "file://%{_datadir}/xml/scrollkeeper/dtds/scrollkeeper-omf.dtd" $CATALOG
# $xmlcatbin --noout --add "system" \
#   "http://..."
#   "file://%{_datadir}/xml/scrollkeeper/dtds/scrollkeeper-omf.dtd" $CATALOG
%define FOR_ROOT_CAT for-catalog-%{name}-%{version}-%{release}.xml
CATALOG=etc/xml/$CATALOG
rm -f %{FOR_ROOT_CAT}.tmp
$xmlcatbin --noout --create %{FOR_ROOT_CAT}.tmp
# $xmlcatbin --noout --add "delegateSystem" \
#   "http://www.oasis-open.org/docbook/xml/simple/" \
#   "file:///$CATALOG" %{FOR_ROOT_CAT}.tmp
$xmlcatbin --noout --add "delegatePublic" \
  "-//OMF//DTD Scrollkeeper OMF Variant V1.0//EN" \
  "file:///$CATALOG" %{FOR_ROOT_CAT}.tmp
# Create tag
sed '/<catalog/a\
  <group id="%{name}-%{version}-%{release}">
/<\/catalog/i\
  </group>' \
  %{FOR_ROOT_CAT}.tmp > %{FOR_ROOT_CAT}

%install
%makeinstall
# scrollkeepr does not export headers or a .pc,
# so it can't be used outside of scrollkeeper
rm $RPM_BUILD_ROOT%{_prefix}/%_lib/libscrollkeeper.*a
rm $RPM_BUILD_ROOT%{_prefix}/%_lib/libscrollkeeper.so
# Unwanted doc stuff
rm -fr $RPM_BUILD_ROOT/var/log/scrollkeeper.log \
  $RPM_BUILD_ROOT%{_datadir}/doc \
  $RPM_BUILD_ROOT%{_localstatedir}/lib
#
# Change sr@Latn to sr@latin
mv %{buildroot}%{_datadir}/locale/sr@Latn %{buildroot}%{_datadir}/locale/sr@latin
# Change no to nb
mv %{buildroot}%{_datadir}/locale/no %{buildroot}%{_datadir}/locale/nb
%find_lang %{name}
# Logrotate
install -d $RPM_BUILD_ROOT/etc/logrotate.d
install -m 644 %{S:1} $RPM_BUILD_ROOT/etc/logrotate.d/%{name}
# xml catalog
cat_dir=%{buildroot}/etc/xml
install -d -m755 $cat_dir
# install -m644 %{name}.xml $RPM_BUILD_ROOT/etc/xml/%{name}.xml
install -m644 %{FOR_ROOT_CAT} %{name}.xml $cat_dir
for binary in %{buildroot}/%{_bindir}/*; do
	mv $binary $binary.sk
done
%fdupes $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT
# %pre
# # rm -rf %{_datadir}/scrollkeeper/Templates || true

%post
/sbin/ldconfig
localstated_r=$(echo %{my_localstatedir}|sed 's:^/::')
# rm -rf /var/lib/scrollkeeper
# mkdir -p var/lib/scrollkeeper
# scrollkeeper-update -p var/lib/scrollkeeper
edit-xml-catalog --group --catalog /etc/xml/suse-catalog.xml \
  --add /etc/xml/%{FOR_ROOT_CAT}
# If the scrollkeeper-config group is in automatic mode, then this
# will also switch all symlinks automatically
update-alternatives \
	--install %{_bindir}/scrollkeeper-config scrollkeeper-config %{_bindir}/scrollkeeper-config.sk 20 \
	--slave %{_bindir}/scrollkeeper-extract scrollkeeper-extract %{_bindir}/scrollkeeper-extract.sk \
	--slave %{_bindir}/scrollkeeper-gen-seriesid scrollkeeper-gen-seriesid %{_bindir}/scrollkeeper-gen-seriesid.sk \
	--slave %{_bindir}/scrollkeeper-get-cl scrollkeeper-get-cl %{_bindir}/scrollkeeper-get-cl.sk \
	--slave %{_bindir}/scrollkeeper-get-content-list scrollkeeper-get-content-list %{_bindir}/scrollkeeper-get-content-list.sk \
	--slave %{_bindir}/scrollkeeper-get-extended-content-list scrollkeeper-get-extended-content-list %{_bindir}/scrollkeeper-get-extended-content-list.sk \
	--slave %{_bindir}/scrollkeeper-get-index-from-docpath scrollkeeper-get-index-from-docpath %{_bindir}/scrollkeeper-get-index-from-docpath.sk \
	--slave %{_bindir}/scrollkeeper-get-toc-from-docpath scrollkeeper-get-toc-from-docpath %{_bindir}/scrollkeeper-get-toc-from-docpath.sk \
	--slave %{_bindir}/scrollkeeper-get-toc-from-id scrollkeeper-get-toc-from-id %{_bindir}/scrollkeeper-get-toc-from-id.sk \
	--slave %{_bindir}/scrollkeeper-install scrollkeeper-install %{_bindir}/scrollkeeper-install.sk \
	--slave %{_bindir}/scrollkeeper-preinstall scrollkeeper-preinstall %{_bindir}/scrollkeeper-preinstall.sk \
	--slave %{_bindir}/scrollkeeper-rebuilddb scrollkeeper-rebuilddb %{_bindir}/scrollkeeper-rebuilddb.sk \
	--slave %{_bindir}/scrollkeeper-uninstall scrollkeeper-uninstall %{_bindir}/scrollkeeper-uninstall.sk \
	--slave %{_bindir}/scrollkeeper-update scrollkeeper-update %{_bindir}/scrollkeeper-update.sk

%postun
localstated_r=$(echo %{my_localstatedir}|sed 's:^/::')
edit-xml-catalog --group --catalog /etc/xml/suse-catalog.xml \
  --del %{name}-%{version}-%{release}
### if [ $1 = 0 ]; then
###   # SK is being removed, not upgraded.
###   # Remove all generated files
###   rm -rf $localstated_r/lib/scrollkeeper
###   rm -f $localstated_r/log/scrollkeeper.log
###   rm -f $localstated_r/log/scrollkeeper.log.1
###   [ -x $r/$xmlcatbin ] || {
###     echo "$r/$xmlcatbin is missing"
###     echo "Cleanup $xmlcatal_g manually"
###     exit 0
###   }
### fi
#rm -rf %{_datadir}/scrollkeeper/templates
/sbin/ldconfig
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/scrollkeeper-config.sk ]; then
  update-alternatives --remove scrollkeeper-config %{_bindir}/scrollkeeper-config.sk
fi

%posttrans
# Workaround old bug in 11.1/11.2 packages that always removed the symlinks in
# %postun. Can be removed during 12.2 development.
if [ ! -f %{_bindir}/scrollkeeper-config -a -f %{_bindir}/scrollkeeper-config.sk ]; then
  update-alternatives \
          --install %{_bindir}/scrollkeeper-config scrollkeeper-config %{_bindir}/scrollkeeper-config.sk 20 \
          --slave %{_bindir}/scrollkeeper-extract scrollkeeper-extract %{_bindir}/scrollkeeper-extract.sk \
          --slave %{_bindir}/scrollkeeper-gen-seriesid scrollkeeper-gen-seriesid %{_bindir}/scrollkeeper-gen-seriesid.sk \
          --slave %{_bindir}/scrollkeeper-get-cl scrollkeeper-get-cl %{_bindir}/scrollkeeper-get-cl.sk \
          --slave %{_bindir}/scrollkeeper-get-content-list scrollkeeper-get-content-list %{_bindir}/scrollkeeper-get-content-list.sk \
          --slave %{_bindir}/scrollkeeper-get-extended-content-list scrollkeeper-get-extended-content-list %{_bindir}/scrollkeeper-get-extended-content-list.sk \
          --slave %{_bindir}/scrollkeeper-get-index-from-docpath scrollkeeper-get-index-from-docpath %{_bindir}/scrollkeeper-get-index-from-docpath.sk \
          --slave %{_bindir}/scrollkeeper-get-toc-from-docpath scrollkeeper-get-toc-from-docpath %{_bindir}/scrollkeeper-get-toc-from-docpath.sk \
          --slave %{_bindir}/scrollkeeper-get-toc-from-id scrollkeeper-get-toc-from-id %{_bindir}/scrollkeeper-get-toc-from-id.sk \
          --slave %{_bindir}/scrollkeeper-install scrollkeeper-install %{_bindir}/scrollkeeper-install.sk \
          --slave %{_bindir}/scrollkeeper-preinstall scrollkeeper-preinstall %{_bindir}/scrollkeeper-preinstall.sk \
          --slave %{_bindir}/scrollkeeper-rebuilddb scrollkeeper-rebuilddb %{_bindir}/scrollkeeper-rebuilddb.sk \
          --slave %{_bindir}/scrollkeeper-uninstall scrollkeeper-uninstall %{_bindir}/scrollkeeper-uninstall.sk \
          --slave %{_bindir}/scrollkeeper-update scrollkeeper-update %{_bindir}/scrollkeeper-update.sk
fi

%files
%defattr(-,root,root)
%doc COPYING AUTHORS README NEWS INSTALL
%config(noreplace) /etc/logrotate.d/%{name}
%config %{_sysconfdir}/%{name}.conf
%config %{_sysconfdir}/xml
%{_datadir}/omf
%{_bindir}/*.sk
%{_libdir}/lib*
%{_mandir}/*/*
%{_datadir}/xml/scrollkeeper
%{_datadir}/scrollkeeper

%files lang -f %{name}.lang

%changelog
* Mon Dec  7 2009 vuntz@opensuse.org
- Rework the update-alternatives part to be correctly handle
  package upgrades. Note that we need a %%posttrans to work around
  bugs in previously installed packages.
* Thu May 28 2009 vuntz@novell.com
- Use update-alternatives for the binaries, and rename all of them
  by default so that rarian-scrollkeeper-compat can be installed at
  the same time.
- Suggests logrotate.
- Rename no to nb locale after installation, so we don't have to
  call autoreconf.
- Remove obsolete checks for old versions of openSUSE.
- Use configure macro.
- Use makeinstall.
- Remove commented out commands.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Fri Jul 18 2008 jpr@novell.com
- Tag patches
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Use /sbin/ldconfig in %%post and add it to %%postun
- Split off a -lang subpackage.
* Mon Jan 29 2007 sbrabec@suse.cz
- Removed references to /opt/gnome.
* Wed Jan 10 2007 prusnak@suse.cz
- removed "-g" flag from CFLAGS in spec file (added accidentaly by last update)
* Wed Jan 10 2007 prusnak@suse.cz
- fix segfault on database directory creation (createdbdir.diff) [#230786]
* Thu Aug 17 2006 ke@suse.de
- Remove SuSEconfig calls and do not build the SK database; yelp on
  openSUSE does not make use of the SK database.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Mon Oct  3 2005 jpr@suse.de
- don't package the .a, .la or .so files
* Wed Aug 24 2005 ke@suse.de
- Reset LC_ALL and LANGUAGE before running scrollkeeper-update.  See bug
  [#] 112642.
* Fri Jul 15 2005 ke@suse.de
- Patch scrollkeeper-rebuilddb.in to prevent %%post from segfaulting in
  the build system; debugged by Stanislav Brabec [# 96609].
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Mon Nov  8 2004 ro@suse.de
- fix last change
* Mon Oct 18 2004 ro@suse.de
- locale rename: no -> nb
* Fri Feb 13 2004 ke@suse.de
- Stop touching /var/adm/SuSEconfig/run-scrollkeeper-update; run
  scrollkeeper-rebuilddb at installation time immediately.
* Wed Dec 10 2003 ke@suse.de
- Update to version 0.3.14; many a lot bug fixes.
  * By default, don't retrieve DTDs from the net.
  * Fix various memory leaks.
  * Update translations.
* Fri Sep 19 2003 ke@suse.de
- Logrotate /var/log/scrollkeeper.log; reported by Stanislav Brabec [#
  31413].
* Tue Sep 16 2003 ke@suse.de
- Do not call scrollkeeper-rebuilddb unnecessarily in
  SuSEconfig.scrollkeeper and use the trigger file more consistently;
  cf. [# 30792].
- In SuSEconfig.scrollkeeper respect SuSEconfig's --nonewpackage
  option; reported by Ulrich Windl [# 30861].
* Tue Sep  9 2003 ke@suse.de
- Add $YAST_IS_RUNNING check to %%post; do not call scrollkeeper-update
  during package installation with YaST; reported by Ulrich Windl
  [# 30235].
* Fri Aug 15 2003 ke@suse.de
- Call %%run_ldconfig in %%post
- Fix SuSEconfig.scrollkeeper to install the database in /var/lib
  instead of /lib; reported by Ludwig Nussel [# 28690].
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jun 16 2003 ke@suse.de
- Add missing directories: %%{_datadir}/omf and %%{_datadir}/xml .
* Tue May 27 2003 ke@suse.de
- Cleanup $RPM_BUILD_ROOT.
- Use edit-xml-catalog in %%post/%%postun for managing /etc/xml/catalog.
- Use /etc/xml/suse-catalog.xml instead of /etc/xml/catalog.
* Fri May  2 2003 ke@suse.de
- PreReq: sgml-skel; it is also neededforbuild.
* Mon Mar  3 2003 ke@suse.de
- Create var/adm/SuSEconfig/run-%%{name} in %%post and remove from %%files
  list; reported by Sebastian Vollath [# 24564].
* Thu Jan 23 2003 ke@suse.de
- Update to version 0.3.12beta-0:
  * Translation updates.
  * Update GNOME categories.
* Mon Jan 20 2003 ke@suse.de
- Update to version 0.3.12beta-0:
  * Translation updates.
  * Fix temp file handling (cf. below Mon Aug 19 16:18:49 CEST 2002).
- Drop obsolete patches: scrollkeeper-0.3.10-tempfiles.patch,
  scrollkeeper-0.3.10-auto.patch.
* Thu Sep  5 2002 ke@suse.de
- Fix variable assignment in SuSEconfig.scrollkeeper [# 18915].
* Fri Aug 23 2002 ke@suse.de
- Add more checks to SuSEconfig.scrollkeeper to prevent the update call
  from connecting to the net.
  Reported by Olaf Hering [# 17646].
* Mon Aug 19 2002 ke@suse.de
- Fix insecure temporary file handling that can lead to elevated
  privileges; apply  scrollkeeper-0.3.10-tempfiles.patch provide by Red
  Hat.
  Thanks for help to Roman Drahtmueller.
* Fri Aug  9 2002 ke@suse.de
- In %%postun check whether xmlcatalog is still installed; if not,
  tell the user to fix the catalog manually.
* Thu Aug  1 2002 ke@suse.de
- Provide PreReq: libxml2 libxslt docbook_4.
* Thu Jul 25 2002 ke@suse.de
- Update to version 0.3.11:
  * Update translations.
  * Get GNOME categories from the Panel.
* Wed Jul 17 2002 ke@suse.de
- Drop obsolete %%pre script to make patchrpm work.
  Reported by "build"; fix proposed by Micheal Schroeder.
* Wed Jul  3 2002 ke@suse.de
- Don't require intltool any longer.
* Mon Jun 24 2002 ke@suse.de
- Update to version 0.3.10 (adjust .auto patch).
* Mon Jun 17 2002 meissner@suse.de
- full auto* and intltool rerun, so it works on ppc64.
- removed # lines from Makefile.am targets.
* Wed May 15 2002 hhetter@suse.de
- fix omfdirs
- the SuSEconfig script now runs scrollkeeper-update
  if packages set the run-scrollkeeper-update flag while
  installation / uninstallation
* Mon May  6 2002 ke@suse.de
- Set %%_libdir to make it build on x86_64.
* Fri May  3 2002 ke@suse.de
- Update to version 0.3.8.
- Provide SuSEconfig scripts to update XML catalogs and to maintain the
  scrollkeeper database.
- Spec file nearly re-written (add Requires, move configure call in
  build section, update %%post/%%postun script.
* Fri Apr 27 2001 hhetter@suse.de
- added libscrollkeeper to filelist
* Tue Apr 24 2001 ke@suse.de
- Update to version 0.2.0; prepared by Daniel Egger (thanks).
* Tue Mar  6 2001 ke@suse.de
- New package: Version 0.1.4.
